@@ -124,6 +124,24 @@ def resize_keeping_aspect_ratio_wrt_longside(img, length,
                           interpolation=cv_interpolation)
 
 
+def resize_keeping_aspect_ratio_wrt_target_size(
+        img, width, height, interpolation='bilinear',
+        background_color=(0, 0, 0)):
+    if width == img.shape[1] and height == img.shape[0]:
+        return img
+    H, W, _ = img.shape
+    ratio = min(float(height) / H, float(width) / W)
+    M = np.array([[ratio, 0, 0],
+                  [0, ratio, 0]], dtype=np.float32)
+    dst = np.zeros((int(height), int(width), 3), dtype=img.dtype)
+    return cv2.warpAffine(
+        img, M,
+        (int(width), int(height)),
+        dst,
+        cv2.INTER_CUBIC, cv2.BORDER_CONSTANT,
+        background_color)
+
+
 def squared_padding_image(img, length=None):
     H, W = img.shape[:2]
     if H > W:
